/**
 * サンプルプログラム: 『<biz-stream_home>/sample/excel_csv/XmlToXlsxSample.java』
 * レイアウトファイルからExcelファイルを生成するサンプルです。
 *
 * @author Copyright 2001-2023 BrainSellers.com Corp. All Rights Reserved.
 * @version 1.2.0
 * @since 1.0.0
 */
import java.io.FileNotFoundException;
import java.io.IOException;

import com.brainsellers.xml.JaxpXML;
import com.brainsellers.xml.common.XMLSuper;
import com.brainsellers.xml.page.ExcelEngine;

class XmlToXlsxSample {
	// XMLファイル名
	private String xml_file = "${base-dir}/sample/excel_csv/ExcelSample_doc.xml";

	// Excelファイル名
	private String xlsx_file = "${base-dir}/sample/excel_csv/XmlToXlsxSample.xlsx";
	// private String xls_file = "${base-dir}/sample/excel_csv/XmlToXlsxSample.xls";

	public static void main(String argv[]) {
		new XmlToXlsxSample(argv);
		System.exit(0);
	}

	/**
	 * コンストラクタ
	 *
	 * @param argv
	 *            起動時の引数
	 */
	public XmlToXlsxSample(String argv[]) {
		try {
			// (1) 出力ファイル名を指定する
			ExcelEngine excel = new ExcelEngine(xlsx_file);

			// (2) ストリーム出力の場合は setFormat を使用して出力ファイル形式を指定する
			// ファイル名指定の場合は、(1)の出力ファイル名で指定した拡張子よりも setFormat で指定したファイル形式が優先される
			// excel.setFormat(ExcelEngine.FORMAT_XLSX); // xlsxファイル形式
			// excel.setFormat(ExcelEngine.FORMAT_XLS);  // xlsファイル形式

			// (3) ワークシートの設定を行う
			excel.setMultiSheet(true);     // 改ページごとにワークシートを生成して出力
			// excel.setMultiSheet(false); // 単一ワークシートに出力

			// (4) 出力はExcel出力エンジンを指定する
			XMLSuper xml = new JaxpXML(xml_file, excel);

			// (5) レイアウト情報(XML)の解析を行う
			xml.parse();

			// (6)データソースを設定する
			// 表のヘッダ
			xml.setDataSource("header-data","${base-dir}/sample/excel_csv/header.csv", "UTF-8");
			// 表の明細データ
			xml.setDataSource("detail-data","${base-dir}/sample/excel_csv/detail.csv", "UTF-8");

			// (7) 座標計算を行う
			xml.calcDataSize();

			// (8) Excelデータの生成
			xml.toPDF();

			// (9) Excelファイルを出力する
			xml.close();

		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
}
